@@ -53,33 +53,39 @@ class Embedder:
             raise ModuleNotFoundError(msg)
 
         # Embed tweets
-        if ('tweet' in nodes_to_embed and
+        if ('tweet' in nodes_to_embed and 'tweet' in nodes and
+                len(nodes['tweet']) > 0 and
                 'text_emb' not in nodes['tweet'].columns):
             nodes['tweet'] = self._embed_tweets(tweet_df=nodes['tweet'])
 
         # Embed replies
-        if ('reply' in nodes_to_embed and
+        if ('reply' in nodes_to_embed and 'reply' in nodes and
+                len(nodes['reply']) > 0 and
                 'text_emb' not in nodes['reply'].columns):
             nodes['reply'] = self._embed_replies(reply_df=nodes['reply'])
 
         # Embed users
-        if ('user' in nodes_to_embed and
+        if ('user' in nodes_to_embed and 'user' in nodes and
+                len(nodes['user']) > 0 and
                 'description_emb' not in nodes['user'].columns):
             nodes['user'] = self._embed_users(user_df=nodes['user'])
 
         # Embed articles
-        if ('article' in nodes_to_embed and
+        if ('article' in nodes_to_embed and 'article' in nodes and
+                len(nodes['article']) > 0 and
                 'content_emb' not in nodes['article'].columns):
             nodes['article'] = \
                     self._embed_articles(article_df=nodes['article'])
 
         # Embed images
-        if ('image' in nodes_to_embed and
+        if ('image' in nodes_to_embed and 'image' in nodes and
+                len(nodes['image']) > 0 and
                 'pixels_emb' not in nodes['image'].columns):
             nodes['image'] = self._embed_images(image_df=nodes['image'])
 
         # Embed claims
-        if ('claim' in nodes_to_embed and
+        if ('claim' in nodes_to_embed and 'claim' in nodes and
+                len(nodes['claim']) > 0 and
                 'reviewer_emb' not in nodes['claim'].columns):
             nodes['claim'] = self._embed_claims(claim_df=nodes['claim'])
 
